@@ -189,7 +189,7 @@ def update(ctx, token, vault, sentinel_tag, agent_tag):
 
 #@click.option('--unlocked', is_flag=True, default=False, help="Vessel workstation is unlocked and the token can be obtained from Vault")
 
-def kubebench(ctx, token, vault):
+def kubebench(ctx, token, vault, vault_info, yaml_dir):
   payload = Payload(token)
   pipeline = Pipeline(start_fn=start, end_fn=end, prompt_fn=prompt)
   pipeline.add(KubebenchStep(vault, vault_info, yaml_dir))
