@@ -9,7 +9,7 @@ from typing import List, Callable, Tuple
 from vessel.pipeline import Step, Payload
 from vessel.logging import logger
 from vessel.version import LATEST_AGENT, LATEST_SENTINEL
-
+from vessel.utilities import sanitizeClusterName
 class DeployAgentStep(Step):
   """
   Deploy Agent
@@ -59,7 +59,7 @@ class GenerateYamlStep(Step):
 
   def _get_keys(self, payload:Payload) -> Tuple[str]:
     if payload.rsa:
-      name = urllib.parse.quote(payload.cluster['result']['name'].lower().replace(" ", "-"))
+      name = sanitizeClusterName(payload.cluster['result']['name'])
       return (name, payload.rsa, payload.vault_user, payload.vault_pwd, payload.distribution)
     else:
       with open(os.path.expanduser(f"~/.daas/{payload.token}/registration.json"), 'r') as f:
@@ -67,7 +67,7 @@ class GenerateYamlStep(Step):
       with open(os.path.expanduser(f"~/.daas/vault.json"), 'r') as f:
         vault = json.load(f)
       
-      name = urllib.parse.quote(registration['cluster']['result']['name'].lower().replace(" ", "-"))
+      name = sanitizeClusterName(registration['cluster']['result']['name'])
       return (name, registration['rsa'], vault['public']['user'], vault['public']['pwd'], registration['distribution'])
 
 
@@ -121,7 +121,7 @@ class GenerateYamlStep(Step):
         - apiVersion: v1
           kind: ConfigMap
           metadata:
-            name: sentinel-tasks-cm
+            name: {name}-sentinel-tasks-cm
           data:
             tasks.json: |
               {{
@@ -142,7 +142,7 @@ class GenerateYamlStep(Step):
                     "name": "anchore",
                     "module": "sentinel.tasks.anchore.Anchore",
                     "enabled": true,
-                    "scheduled": 43200
+                    "scheduled": 3600
                   }},
                   {{
                     "name": "events",
@@ -169,7 +169,7 @@ class GenerateYamlStep(Step):
                 volumes:
                   - name: tasks-volume
                     configMap:
-                      name: sentinel-tasks-cm
+                      name: {name}-sentinel-tasks-cm
                 containers:
                 - name: {name}-sentinel
                   image: docker-registry.oc.corp.sourcesense.com/daas/workstation-sentinel:{tag}
